@@ -43,7 +43,6 @@ YAML_EXCLUDE_PATTERNS = ['.tox', '.testrepository', '.git',
 KOLLA_NETWORKS = [
     'api',
     'storage',
-    'cluster',
     'swift_storage',
     'swift_replication',
     'migration',
@@ -124,9 +123,11 @@ def check_json_j2():
         context = {
             'hostvars': hostvars(),
             'groups': groups(),
-            'cluster_interface': 'cluster_interface',
+            'inventory_hostname': 'hostname',
+            'api_interface_address': '',
+            'kolla_internal_fqdn': '',
+            'octavia_provider_drivers': '',
             'storage_interface': 'storage_interface',
-            'inventory_hostname': 'hostname'
         }
         data = template.render(**context)
         json.loads(data)
